@@ -13,38 +13,46 @@
 # limitations under the License.
 
 """Test PyMongo with a variety of greenlet-based monkey-patching frameworks."""
+from __future__ import annotations
 
 import getopt
 import sys
 
+import pytest
+
 
 def run_gevent():
     """Prepare to run tests with Gevent. Can raise ImportError."""
     from gevent import monkey
+
     monkey.patch_all()
 
 
 def run_eventlet():
     """Prepare to run tests with Eventlet. Can raise ImportError."""
     import eventlet
+
     # https://github.com/eventlet/eventlet/issues/401
     eventlet.sleep()
     eventlet.monkey_patch()
 
 
 FRAMEWORKS = {
-    'gevent': run_gevent,
-    'eventlet': run_eventlet,
+    "gevent": run_gevent,
+    "eventlet": run_eventlet,
 }
 
 
 def list_frameworks():
     """Tell the user what framework names are valid."""
-    sys.stdout.write("""Testable frameworks: %s
+    sys.stdout.write(
+        """Testable frameworks: %s
 
 Note that membership in this list means the framework can be tested with
 PyMongo, not necessarily that it is officially supported.
-""" % ", ".join(sorted(FRAMEWORKS)))
+"""
+        % ", ".join(sorted(FRAMEWORKS))
+    )
 
 
 def run(framework_name, *args):
@@ -53,20 +61,18 @@ def run(framework_name, *args):
     FRAMEWORKS[framework_name]()
 
     # Run the tests.
-    sys.argv[:] = ['setup.py', 'test'] + list(args)
-    import setup
+    sys.exit(pytest.main(list(args)))
 
 
 def main():
     """Parse options and run tests."""
-    usage = """python %s FRAMEWORK_NAME
+    usage = f"""python {sys.argv[0]} FRAMEWORK_NAME
 
 Test PyMongo with a variety of greenlet-based monkey-patching frameworks. See
-python %s --help-frameworks.""" % (sys.argv[0], sys.argv[0])
+python {sys.argv[0]} --help-frameworks."""
 
     try:
-        opts, args = getopt.getopt(
-            sys.argv[1:], "h", ["help", "help-frameworks"])
+        opts, args = getopt.getopt(sys.argv[1:], "h", ["help", "help-frameworks"])
     except getopt.GetoptError as err:
         print(str(err))
         print(usage)
@@ -80,20 +86,21 @@ python %s --help-frameworks.""" % (sys.argv[0], sys.argv[0])
             list_frameworks()
             sys.exit()
         else:
-            assert False, "unhandled option"
+            raise AssertionError("unhandled option")
 
     if not args:
         print(usage)
         sys.exit(1)
 
     if args[0] not in FRAMEWORKS:
-        print('%r is not a testable framework.\n' % args[0])
+        print("%r is not a testable framework.\n" % args[0])
         list_frameworks()
         sys.exit(1)
 
-    run(args[0],    # Framework name.
-        *args[1:])  # Command line args to setup.py, like what test to run.
+    run(
+        args[0], *args[1:]  # Framework name.
+    )  # Command line args to pytest, like what test to run.
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
