@@ -13,6 +13,7 @@
 # limitations under the License.
 
 """Test suite for pymongo, bson, and gridfs."""
+from __future__ import annotations
 
 import base64
 import gc
@@ -29,15 +30,7 @@ import unittest
 import warnings
 
 try:
-    from xmlrunner import XMLTestRunner
-
-    HAVE_XML = True
-# ValueError is raised when version 3+ is installed on Jython 2.7.
-except (ImportError, ValueError):
-    HAVE_XML = False
-
-try:
-    import ipaddress  # noqa
+    import ipaddress
 
     HAVE_IPADDRESS = True
 except ImportError:
@@ -64,15 +57,6 @@ from pymongo.uri_parser import parse_uri
 if HAVE_SSL:
     import ssl
 
-try:
-    # Enable the fault handler to dump the traceback of each running thread
-    # after a segfault.
-    import faulthandler
-
-    faulthandler.enable()
-except ImportError:
-    pass
-
 # Enable debug output for uncollectable objects. PyPy does not have set_debug.
 if hasattr(gc, "set_debug"):
     gc.set_debug(
@@ -103,6 +87,7 @@ TEST_LOADBALANCER = bool(os.environ.get("TEST_LOADBALANCER"))
 TEST_SERVERLESS = bool(os.environ.get("TEST_SERVERLESS"))
 SINGLE_MONGOS_LB_URI = os.environ.get("SINGLE_MONGOS_LB_URI")
 MULTI_MONGOS_LB_URI = os.environ.get("MULTI_MONGOS_LB_URI")
+
 if TEST_LOADBALANCER:
     res = parse_uri(SINGLE_MONGOS_LB_URI or "")
     host, port = res["nodelist"][0]
@@ -323,7 +308,10 @@ class ClientContext:
     @property
     def hello(self):
         if not self._hello:
-            self._hello = self.client.admin.command(HelloCompat.LEGACY_CMD)
+            if self.serverless or self.load_balancer:
+                self._hello = self.client.admin.command(HelloCompat.CMD)
+            else:
+                self._hello = self.client.admin.command(HelloCompat.LEGACY_CMD)
         return self._hello
 
     def _connect(self, host, port, **kwargs):
@@ -333,7 +321,7 @@ class ClientContext:
         )
         try:
             try:
-                client.admin.command(HelloCompat.LEGACY_CMD)  # Can we connect?
+                client.admin.command("ping")  # Can we connect?
             except pymongo.errors.OperationFailure as exc:
                 # SERVER-32063
                 self.connection_attempts.append(
@@ -351,7 +339,6 @@ class ClientContext:
 
     def _init_client(self):
         self.client = self._connect(host, port)
-
         if self.client is not None:
             # Return early when connected to dataLake as mongohoused does not
             # support the getCmdLineOpts command and is tested without TLS.
@@ -809,11 +796,12 @@ class ClientContext:
             return True
         return False
 
-    def require_cluster_type(self, topologies=[]):  # noqa
+    def require_cluster_type(self, topologies=None):
         """Run a test only if the client is connected to a cluster that
         conforms to one of the specified topologies. Acceptable topologies
         are 'single', 'replicaset', and 'sharded'.
         """
+        topologies = topologies or []
 
         def _is_valid_topology():
             return self.is_topology_type(topologies)
@@ -1183,9 +1171,9 @@ def print_running_topology(topology):
     if running:
         print(
             "WARNING: found Topology with running threads:\n"
-            "  Threads: {}\n"
-            "  Topology: {}\n"
-            "  Creation traceback:\n{}".format(running, topology, topology._settings._stack)
+            f"  Threads: {running}\n"
+            f"  Topology: {topology}\n"
+            f"  Creation traceback:\n{topology._settings._stack}"
         )
 
 
@@ -1236,24 +1224,6 @@ def teardown():
     print_running_clients()
 
 
-class PymongoTestRunner(unittest.TextTestRunner):
-    def run(self, test):
-        setup()
-        result = super().run(test)
-        teardown()
-        return result
-
-
-if HAVE_XML:
-
-    class PymongoXMLTestRunner(XMLTestRunner):  # type: ignore[misc]
-        def run(self, test):
-            setup()
-            result = super().run(test)
-            teardown()
-            return result
-
-
 def test_cases(suite):
     """Iterator over all TestCases within a TestSuite."""
     for suite_or_case in suite._tests:
@@ -1270,7 +1240,7 @@ def clear_warning_registry():
     """Clear the __warningregistry__ for all modules."""
     for _, module in list(sys.modules.items()):
         if hasattr(module, "__warningregistry__"):
-            setattr(module, "__warningregistry__", {})  # noqa
+            module.__warningregistry__ = {}  # type:ignore[attr-defined]
 
 
 class SystemCertsPatcher:
