@@ -13,6 +13,7 @@
 # limitations under the License.
 
 """Authentication Tests."""
+from __future__ import annotations
 
 import os
 import sys
@@ -60,7 +61,7 @@ class AutoAuthenticateThread(threading.Thread):
     """Used in testing threaded authentication.
 
     This does collection.find_one() with a 1-second delay to ensure it must
-    check out and authenticate multiple sockets from the pool concurrently.
+    check out and authenticate multiple connections from the pool concurrently.
 
     :Parameters:
       `collection`: An auth-protected collection containing one document.
@@ -179,7 +180,7 @@ class TestGSSAPI(unittest.TestCase):
 
                 client[GSSAPI_DB].list_collection_names()
 
-                uri = uri + f"&replicaSet={str(set_name)}"
+                uri = uri + f"&replicaSet={set_name!s}"
                 client = MongoClient(uri)
                 client[GSSAPI_DB].list_collection_names()
 
@@ -196,7 +197,7 @@ class TestGSSAPI(unittest.TestCase):
 
             client[GSSAPI_DB].list_collection_names()
 
-            mech_uri = mech_uri + f"&replicaSet={str(set_name)}"
+            mech_uri = mech_uri + f"&replicaSet={set_name!s}"
             client = MongoClient(mech_uri)
             client[GSSAPI_DB].list_collection_names()
 
@@ -217,7 +218,7 @@ class TestGSSAPI(unittest.TestCase):
 
         # Need one document in the collection. AutoAuthenticateThread does
         # collection.find_one with a 1-second delay, forcing it to check out
-        # multiple sockets from the pool concurrently, proving that
+        # multiple connections from the pool concurrently, proving that
         # auto-authentication works with GSSAPI.
         collection = db.test
         if not collection.count_documents({}):
