@@ -13,6 +13,7 @@
 # limitations under the License.
 
 """Test the collection module."""
+from __future__ import annotations
 
 import contextlib
 import re
@@ -276,7 +277,6 @@ class TestCollection(IntegrationTest):
         db = self.db
 
         self.assertRaises(TypeError, db.test.create_index, 5)
-        self.assertRaises(TypeError, db.test.create_index, {"hello": 1})
         self.assertRaises(ValueError, db.test.create_index, [])
 
         db.test.drop_indexes()
@@ -483,7 +483,7 @@ class TestCollection(IntegrationTest):
         db.test.drop_indexes()
         self.assertEqual("geo_2dsphere", db.test.create_index([("geo", GEOSPHERE)]))
 
-        for _dummy, info in db.test.index_information().items():
+        for dummy, info in db.test.index_information().items():
             field, idx_type = info["key"][0]
             if field == "geo" and idx_type == "2dsphere":
                 break
@@ -502,7 +502,7 @@ class TestCollection(IntegrationTest):
         db.test.drop_indexes()
         self.assertEqual("a_hashed", db.test.create_index([("a", HASHED)]))
 
-        for _dummy, info in db.test.index_information().items():
+        for dummy, info in db.test.index_information().items():
             field, idx_type = info["key"][0]
             if field == "a" and idx_type == "hashed":
                 break
@@ -716,7 +716,7 @@ class TestCollection(IntegrationTest):
         self.assertEqual(document["_id"], result.inserted_id)
         self.assertFalse(result.acknowledged)
         # The insert failed duplicate key...
-        wait_until(lambda: 2 == db.test.count_documents({}), "forcing duplicate key error")
+        wait_until(lambda: db.test.count_documents({}) == 2, "forcing duplicate key error")
 
         document = RawBSONDocument(encode({"_id": ObjectId(), "foo": "bar"}))
         result = db.test.insert_one(document)
@@ -817,7 +817,7 @@ class TestCollection(IntegrationTest):
         self.assertTrue(isinstance(result, DeleteResult))
         self.assertRaises(InvalidOperation, lambda: result.deleted_count)
         self.assertFalse(result.acknowledged)
-        wait_until(lambda: 0 == db.test.count_documents({}), "delete 1 documents")
+        wait_until(lambda: db.test.count_documents({}) == 0, "delete 1 documents")
 
     def test_delete_many(self):
         self.db.test.drop()
@@ -838,7 +838,7 @@ class TestCollection(IntegrationTest):
         self.assertTrue(isinstance(result, DeleteResult))
         self.assertRaises(InvalidOperation, lambda: result.deleted_count)
         self.assertFalse(result.acknowledged)
-        wait_until(lambda: 0 == db.test.count_documents({}), "delete 2 documents")
+        wait_until(lambda: db.test.count_documents({}) == 0, "delete 2 documents")
 
     def test_command_document_too_large(self):
         large = "*" * (client_context.max_bson_size + _COMMAND_OVERHEAD)
@@ -1538,7 +1538,7 @@ class TestCollection(IntegrationTest):
         while True:
             cursor.next()
             n += 1
-            if 3 == n:
+            if n == 3:
                 self.assertFalse(cursor.alive)
                 break
 
@@ -1721,15 +1721,15 @@ class TestCollection(IntegrationTest):
         # Make sure the socket is returned after exhaustion.
         cur = client[self.db.name].test.find(cursor_type=CursorType.EXHAUST)
         next(cur)
-        self.assertEqual(0, len(pool.sockets))
+        self.assertEqual(0, len(pool.conns))
         for _ in cur:
             pass
-        self.assertEqual(1, len(pool.sockets))
+        self.assertEqual(1, len(pool.conns))
 
         # Same as previous but don't call next()
         for _ in client[self.db.name].test.find(cursor_type=CursorType.EXHAUST):
             pass
-        self.assertEqual(1, len(pool.sockets))
+        self.assertEqual(1, len(pool.conns))
 
         # If the Cursor instance is discarded before being completely iterated
         # and the socket has pending data (more_to_come=True) we have to close
@@ -1742,7 +1742,7 @@ class TestCollection(IntegrationTest):
                 next(cur)
         else:
             next(cur)
-        self.assertEqual(0, len(pool.sockets))
+        self.assertEqual(0, len(pool.conns))
         if sys.platform.startswith("java") or "PyPy" in sys.version:
             # Don't wait for GC or use gc.collect(), it's unreliable.
             cur.close()
@@ -1750,7 +1750,7 @@ class TestCollection(IntegrationTest):
         # Wait until the background thread returns the socket.
         wait_until(lambda: pool.active_sockets == 0, "return socket")
         # The socket should be discarded.
-        self.assertEqual(0, len(pool.sockets))
+        self.assertEqual(0, len(pool.conns))
 
     def test_distinct(self):
         self.db.drop_collection("test")
@@ -1849,7 +1849,7 @@ class TestCollection(IntegrationTest):
         unack_coll = db.collection_2.with_options(write_concern=WriteConcern(w=0))
         unack_coll.insert_many(insert_second_fails)
         wait_until(
-            lambda: 1 == db.collection_2.count_documents({}), "insert 1 document", timeout=60
+            lambda: db.collection_2.count_documents({}) == 1, "insert 1 document", timeout=60
         )
 
         db.collection_2.drop()
@@ -1879,7 +1879,7 @@ class TestCollection(IntegrationTest):
 
         # Only the first and third documents are inserted.
         wait_until(
-            lambda: 2 == db.collection_4.count_documents({}), "insert 2 documents", timeout=60
+            lambda: db.collection_4.count_documents({}) == 2, "insert 2 documents", timeout=60
         )
 
         db.collection_4.drop()
