@@ -13,6 +13,7 @@
 # limitations under the License.
 
 """Test maxStalenessSeconds support."""
+from __future__ import annotations
 
 import os
 import sys
@@ -123,6 +124,9 @@ class TestMaxStaleness(unittest.TestCase):
         time.sleep(1)
         server = client._topology.select_server(writable_server_selector)
         second = server.description.last_write_date
+        assert first is not None
+
+        assert second is not None
         self.assertGreater(second, first)
         self.assertLess(second, first + 10)
 
