@@ -11,6 +11,7 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
+from __future__ import annotations
 
 import copy
 import datetime
@@ -1084,10 +1085,15 @@ class TestCommandMonitoring(IntegrationTest):
 
         self.listener.reset()
         cmd = SON([("getnonce", 1)])
-        listeners.publish_command_start(cmd, "pymongo_test", 12345, self.client.address)
+        listeners.publish_command_start(cmd, "pymongo_test", 12345, self.client.address)  # type: ignore[arg-type]
         delta = datetime.timedelta(milliseconds=100)
         listeners.publish_command_success(
-            delta, {"nonce": "e474f4561c5eb40b", "ok": 1.0}, "getnonce", 12345, self.client.address
+            delta,
+            {"nonce": "e474f4561c5eb40b", "ok": 1.0},
+            "getnonce",
+            12345,
+            self.client.address,  # type: ignore[arg-type]
+            database_name="pymongo_test",
         )
         started = self.listener.started_events[0]
         succeeded = self.listener.succeeded_events[0]
@@ -1148,9 +1154,9 @@ class TestGlobalListener(IntegrationTest):
 
 class TestEventClasses(unittest.TestCase):
     def test_command_event_repr(self):
-        request_id, connection_id, operation_id = 1, ("localhost", 27017), 2
+        request_id, connection_id, operation_id, db_name = 1, ("localhost", 27017), 2, "admin"
         event = monitoring.CommandStartedEvent(
-            {"ping": 1}, "admin", request_id, connection_id, operation_id
+            {"ping": 1}, db_name, request_id, connection_id, operation_id
         )
         self.assertEqual(
             repr(event),
@@ -1159,20 +1165,20 @@ class TestEventClasses(unittest.TestCase):
         )
         delta = datetime.timedelta(milliseconds=100)
         event = monitoring.CommandSucceededEvent(
-            delta, {"ok": 1}, "ping", request_id, connection_id, operation_id
+            delta, {"ok": 1}, "ping", request_id, connection_id, operation_id, database_name=db_name
         )
         self.assertEqual(
             repr(event),
-            "<CommandSucceededEvent ('localhost', 27017) "
+            "<CommandSucceededEvent ('localhost', 27017) db: 'admin', "
             "command: 'ping', operation_id: 2, duration_micros: 100000, "
             "service_id: None>",
         )
         event = monitoring.CommandFailedEvent(
-            delta, {"ok": 0}, "ping", request_id, connection_id, operation_id
+            delta, {"ok": 0}, "ping", request_id, connection_id, operation_id, database_name=db_name
         )
         self.assertEqual(
             repr(event),
-            "<CommandFailedEvent ('localhost', 27017) "
+            "<CommandFailedEvent ('localhost', 27017) db: 'admin', "
             "command: 'ping', operation_id: 2, duration_micros: 100000, "
             "failure: {'ok': 0}, service_id: None>",
         )
@@ -1180,7 +1186,9 @@ class TestEventClasses(unittest.TestCase):
     def test_server_heartbeat_event_repr(self):
         connection_id = ("localhost", 27017)
         event = monitoring.ServerHeartbeatStartedEvent(connection_id)
-        self.assertEqual(repr(event), "<ServerHeartbeatStartedEvent ('localhost', 27017)>")
+        self.assertEqual(
+            repr(event), "<ServerHeartbeatStartedEvent ('localhost', 27017) awaited: False>"
+        )
         delta = 0.1
         event = monitoring.ServerHeartbeatSucceededEvent(
             delta, {"ok": 1}, connection_id  # type: ignore[arg-type]
