@@ -11,14 +11,19 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
+from __future__ import annotations
 
 import datetime
+import sys
 import uuid
+
+sys.path[0:0] = [""]
+
 from test import client_context, unittest
 from test.test_client import IntegrationTest
 
 from bson import decode, encode
-from bson.binary import JAVA_LEGACY, Binary
+from bson.binary import JAVA_LEGACY, Binary, UuidRepresentation
 from bson.codec_options import CodecOptions
 from bson.errors import InvalidBSON
 from bson.raw_bson import DEFAULT_RAW_BSON_OPTIONS, RawBSONDocument
@@ -27,9 +32,9 @@ from bson.son import SON
 
 class TestRawBSONDocument(IntegrationTest):
 
-    # {u'_id': ObjectId('556df68b6e32ab21a95e0785'),
-    #  u'name': u'Sherlock',
-    #  u'addresses': [{u'street': u'Baker Street'}]}
+    # {'_id': ObjectId('556df68b6e32ab21a95e0785'),
+    #  'name': 'Sherlock',
+    #  'addresses': [{'street': 'Baker Street'}]}
     bson_string = (
         b"Z\x00\x00\x00\x07_id\x00Um\xf6\x8bn2\xab!\xa9^\x07\x85\x02name\x00\t"
         b"\x00\x00\x00Sherlock\x00\x04addresses\x00&\x00\x00\x00\x030\x00\x1e"
@@ -37,11 +42,6 @@ class TestRawBSONDocument(IntegrationTest):
     )
     document = RawBSONDocument(bson_string)
 
-    @classmethod
-    def setUpClass(cls):
-        super(TestRawBSONDocument, cls).setUpClass()
-        cls.client = client_context.client
-
     def tearDown(self):
         if client_context.connected:
             self.client.pymongo_test.test_raw.drop()
@@ -77,6 +77,7 @@ class TestRawBSONDocument(IntegrationTest):
         )
         db.test_raw.insert_one(self.document)
         result = db.test_raw.find_one(self.document["_id"])
+        assert result is not None
         self.assertIsInstance(result, RawBSONDocument)
         self.assertEqual(dict(self.document.items()), dict(result.items()))
 
@@ -87,15 +88,23 @@ class TestRawBSONDocument(IntegrationTest):
         doc = {"_id": 1, "bin4": Binary(uid.bytes, 4), "bin3": Binary(uid.bytes, 3)}
         raw = RawBSONDocument(encode(doc))
         coll.insert_one(raw)
-        self.assertEqual(coll.find_one(), {"_id": 1, "bin4": uid, "bin3": uid})
+        self.assertEqual(coll.find_one(), doc)
+        uuid_coll = coll.with_options(
+            codec_options=coll.codec_options.with_options(
+                uuid_representation=UuidRepresentation.STANDARD
+            )
+        )
+        self.assertEqual(
+            uuid_coll.find_one(), {"_id": 1, "bin4": uid, "bin3": Binary(uid.bytes, 3)}
+        )
 
         # Test that the raw bytes haven't changed.
         raw_coll = coll.with_options(codec_options=DEFAULT_RAW_BSON_OPTIONS)
         self.assertEqual(raw_coll.find_one(), raw)
 
     def test_with_codec_options(self):
-        # {u'date': datetime.datetime(2015, 6, 3, 18, 40, 50, 826000),
-        #  u'_id': UUID('026fab8f-975f-4965-9fbf-85ad874c60ff')}
+        # {'date': datetime.datetime(2015, 6, 3, 18, 40, 50, 826000),
+        #  '_id': UUID('026fab8f-975f-4965-9fbf-85ad874c60ff')}
         # encoded with JAVA_LEGACY uuid representation.
         bson_string = (
             b"-\x00\x00\x00\x05_id\x00\x10\x00\x00\x00\x03eI_\x97\x8f\xabo\x02"
@@ -136,12 +145,13 @@ class TestRawBSONDocument(IntegrationTest):
         db = self.client.pymongo_test
         db.test_raw.insert_one(doc)
         result = db.test_raw.find_one()
+        assert result is not None
         self.assertEqual(decode(self.document.raw), result["embedded"])
 
         # Make sure that CodecOptions are preserved.
         # {'embedded': [
-        #   {u'date': datetime.datetime(2015, 6, 3, 18, 40, 50, 826000),
-        #    u'_id': UUID('026fab8f-975f-4965-9fbf-85ad874c60ff')}
+        #   {'date': datetime.datetime(2015, 6, 3, 18, 40, 50, 826000),
+        #    '_id': UUID('026fab8f-975f-4965-9fbf-85ad874c60ff')}
         # ]}
         # encoded with JAVA_LEGACY uuid representation.
         bson_string = (
@@ -162,6 +172,7 @@ class TestRawBSONDocument(IntegrationTest):
         result = db.get_collection(
             "test_raw", codec_options=CodecOptions(uuid_representation=JAVA_LEGACY)
         ).find_one()
+        assert result is not None
         self.assertEqual(rbd["embedded"][0]["_id"], result["embedded"][0]["_id"])
 
     @client_context.require_connection
@@ -188,3 +199,7 @@ class TestRawBSONDocument(IntegrationTest):
 
         for rkey, elt in zip(rawdoc, keyvaluepairs):
             self.assertEqual(rkey, elt[0])
+
+
+if __name__ == "__main__":
+    unittest.main()
