@@ -13,6 +13,7 @@
 # limitations under the License.
 
 """Test retryable reads spec."""
+from __future__ import annotations
 
 import os
 import pprint
@@ -31,7 +32,7 @@ from test import (
 from test.utils import (
     CMAPListener,
     OvertCommandListener,
-    TestCreator,
+    SpecTestCreator,
     rs_or_single_client,
 )
 from test.utils_spec_runner import SpecRunner
@@ -138,7 +139,7 @@ def create_test(scenario_def, test, name):
     return run_scenario
 
 
-test_creator = TestCreator(create_test, TestSpec, _TEST_PATH)
+test_creator = SpecTestCreator(create_test, TestSpec, _TEST_PATH)
 test_creator.create_tests()
 
 
