@@ -13,6 +13,7 @@
 # limitations under the License.
 
 """Test retryable writes."""
+from __future__ import annotations
 
 import copy
 import os
@@ -28,7 +29,7 @@ from test.utils import (
     DeprecationFilter,
     EventListener,
     OvertCommandListener,
-    TestCreator,
+    SpecTestCreator,
     rs_or_single_client,
 )
 from test.utils_spec_runner import SpecRunner
@@ -120,7 +121,7 @@ def create_test(scenario_def, test, name):
     return run_scenario
 
 
-test_creator = TestCreator(create_test, TestAllScenarios, _TEST_PATH)
+test_creator = SpecTestCreator(create_test, TestAllScenarios, _TEST_PATH)
 test_creator.create_tests()
 
 
