@@ -13,13 +13,14 @@
 # limitations under the License.
 
 """Test the topology module's Server Selection Spec implementation."""
+from __future__ import annotations
 
 import os
 import threading
 from test import IntegrationTest, client_context, unittest
 from test.utils import (
     OvertCommandListener,
-    TestCreator,
+    SpecTestCreator,
     get_pool,
     rs_client,
     wait_until,
@@ -76,7 +77,7 @@ def create_test(scenario_def, test, name):
     return run_scenario
 
 
-class CustomTestCreator(TestCreator):
+class CustomSpecTestCreator(SpecTestCreator):
     def tests(self, scenario_def):
         """Extract the tests from a spec file.
 
@@ -86,7 +87,7 @@ class CustomTestCreator(TestCreator):
         return [scenario_def]
 
 
-CustomTestCreator(create_test, TestAllScenarios, TEST_PATH).create_tests()
+CustomSpecTestCreator(create_test, TestAllScenarios, TEST_PATH).create_tests()
 
 
 class FinderThread(threading.Thread):
@@ -141,7 +142,7 @@ class TestProse(IntegrationTest):
         )
         self.addCleanup(client.close)
         wait_until(lambda: len(client.nodes) == 2, "discover both nodes")
-        wait_until(lambda: len(get_pool(client).sockets) >= 10, "create 10 connections")
+        wait_until(lambda: len(get_pool(client).conns) >= 10, "create 10 connections")
         # Delay find commands on
         delay_finds = {
             "configureFailPoint": "failCommand",
