@@ -13,6 +13,7 @@
 # limitations under the License.
 
 """Execute Transactions Spec tests."""
+from __future__ import annotations
 
 import os
 import sys
@@ -23,12 +24,13 @@ sys.path[0:0] = [""]
 from test import client_context, unittest
 from test.utils import (
     OvertCommandListener,
-    TestCreator,
+    SpecTestCreator,
     rs_client,
     single_client,
     wait_until,
 )
 from test.utils_spec_runner import SpecRunner
+from typing import List
 
 from bson import encode
 from bson.raw_bson import RawBSONDocument
@@ -335,10 +337,12 @@ class TestTransactions(TransactionsBase):
         self.addCleanup(client.close)
         self.addCleanup(coll.drop)
         large_str = "\0" * (1 * 1024 * 1024)
-        ops = [InsertOne(RawBSONDocument(encode({"a": large_str}))) for _ in range(48)]
+        ops: List[InsertOne[RawBSONDocument]] = [
+            InsertOne(RawBSONDocument(encode({"a": large_str}))) for _ in range(48)
+        ]
         with client.start_session() as session:
             with session.start_transaction():
-                coll.bulk_write(ops, session=session)
+                coll.bulk_write(ops, session=session)  # type: ignore[arg-type]
         # Assert commands were constructed properly.
         self.assertEqual(
             ["insert", "insert", "commitTransaction"], listener.started_command_names()
@@ -581,11 +585,11 @@ def create_test(scenario_def, test, name):
     return run_scenario
 
 
-test_creator = TestCreator(create_test, TestTransactions, TEST_PATH)
+test_creator = SpecTestCreator(create_test, TestTransactions, TEST_PATH)
 test_creator.create_tests()
 
 
-TestCreator(
+SpecTestCreator(
     create_test, TestTransactionsConvenientAPI, TestTransactionsConvenientAPI.TEST_PATH
 ).create_tests()
 
