@@ -15,6 +15,8 @@
 """Test that each file in mypy_fails/ actually fails mypy, and test some
 sample client code that uses PyMongo typings.
 """
+from __future__ import annotations
+
 import os
 import sys
 import tempfile
@@ -36,7 +38,7 @@ try:
         year: int
 
     class ImplicitMovie(TypedDict):
-        _id: NotRequired[ObjectId]
+        _id: NotRequired[ObjectId]  # pyright: ignore[reportGeneralTypeIssues]
         name: str
         year: int
 
@@ -242,6 +244,11 @@ class TestDecode(unittest.TestCase):
         rt_document3 = decode(bsonbytes2, codec_options=codec_options2)
         assert rt_document3.raw
 
+    def test_bson_decode_no_codec_option(self) -> None:
+        doc = decode_all(encode({"a": 1}))
+        assert doc
+        doc[0]["a"] = 2
+
     def test_bson_decode_all(self) -> None:
         doc = {"_id": 1}
         bsonbytes = encode(doc)
@@ -266,6 +273,15 @@ class TestDecode(unittest.TestCase):
         rt_documents3 = decode_all(bsonbytes3, codec_options3)
         assert rt_documents3[0].raw
 
+    def test_bson_decode_all_no_codec_option(self) -> None:
+        docs = decode_all(b"")
+        docs.append({"new": 1})
+
+        docs = decode_all(encode({"a": 1}))
+        assert docs
+        docs[0]["a"] = 2
+        docs.append({"new": 1})
+
     def test_bson_decode_iter(self) -> None:
         doc = {"_id": 1}
         bsonbytes = encode(doc)
@@ -290,6 +306,11 @@ class TestDecode(unittest.TestCase):
         rt_documents3 = decode_iter(bsonbytes3, codec_options3)
         assert next(rt_documents3).raw
 
+    def test_bson_decode_iter_no_codec_option(self) -> None:
+        doc = next(decode_iter(encode({"a": 1})))
+        assert doc
+        doc["a"] = 2
+
     def make_tempfile(self, content: bytes) -> Any:
         fileobj = tempfile.TemporaryFile()
         fileobj.write(content)
@@ -324,6 +345,12 @@ class TestDecode(unittest.TestCase):
         rt_documents3 = decode_file_iter(fileobj3, codec_options3)
         assert next(rt_documents3).raw
 
+    def test_bson_decode_file_iter_none_codec_option(self) -> None:
+        fileobj = self.make_tempfile(encode({"new": 1}))
+        doc = next(decode_file_iter(fileobj))
+        assert doc
+        doc["a"] = 2
+
 
 class TestDocumentType(unittest.TestCase):
     @only_type_check
