@@ -11,6 +11,7 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
+from __future__ import annotations
 
 import os
 import sys
@@ -65,6 +66,12 @@ class TestMatchEvaluatorUtil(unittest.TestCase):
         for actual in [{}, {"x": {}}, {"x": {"y": 2}}]:
             self.match_evaluator.match_result(spec, actual)
 
+        spec = {"y": {"$$unsetOrMatches": {"$$exists": True}}}
+        self.match_evaluator.match_result(spec, {})
+        self.match_evaluator.match_result(spec, {"y": 2})
+        self.match_evaluator.match_result(spec, {"x": 1})
+        self.match_evaluator.match_result(spec, {"y": {}})
+
     def test_type(self):
         self.match_evaluator.match_result(
             {
